==> jc-1.4.0.tar.gz: javax/naming/ReferralException.h <==
// public abstract class javax.naming.ReferralException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fadee18b7599c8d5 javax_naming_NamingException
// @dep_class 7961821e227a0a49 javax_naming_ReferralException

// header file dependencies
// @dep_header javax_naming_NamingException

#include "javax/naming/NamingException.h"

#ifndef _JC_javax_naming_ReferralException_H_
#define _JC_javax_naming_ReferralException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_naming_Context$object;

// Typedefs
typedef struct _jc_javax_naming_ReferralException$sub_refs	_jc_javax_naming_ReferralException$sub_refs;
typedef struct _jc_javax_naming_ReferralException$sub_nonrefs	_jc_javax_naming_ReferralException$sub_nonrefs;
typedef struct _jc_javax_naming_ReferralException$refs	_jc_javax_naming_ReferralException$refs;
typedef struct _jc_javax_naming_ReferralException$nonrefs	_jc_javax_naming_ReferralException$nonrefs;
typedef struct _jc_javax_naming_ReferralException$object	_jc_javax_naming_ReferralException$object;

typedef struct _jc_javax_naming_ReferralException$fields_struct	_jc_javax_naming_ReferralException$fields_struct;
typedef const struct _jc_javax_naming_ReferralException$vmethods	_jc_javax_naming_ReferralException$vmethods;
typedef const struct _jc_javax_naming_ReferralException$vtable	_jc_javax_naming_ReferralException$vtable;
typedef const struct _jc_javax_naming_ReferralException$vtype	_jc_javax_naming_ReferralException$vtype;

// Class fields structure
struct _jc_javax_naming_ReferralException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_naming_ReferralException$fields_struct _jc_javax_naming_ReferralException$class_fields;

// Constructors
extern void _jc_javax_naming_ReferralException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_ReferralException$object *);
extern void _jc_javax_naming_ReferralException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_ReferralException$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_naming_ReferralException$method$getReferralContext$ffdbd6221eb269af(_jc_env *, struct _jc_javax_naming_ReferralException$object *);
extern struct _jc_object *_jc_javax_naming_ReferralException$method$getReferralContext$f81f12c3eb996fff(_jc_env *, struct _jc_javax_naming_ReferralException$object *, struct _jc_java_util_Hashtable$object *);
extern struct _jc_java_lang_Object$object *_jc_javax_naming_ReferralException$method$getReferralInfo$d16117d1086fa452(_jc_env *, struct _jc_javax_naming_ReferralException$object *);
extern void _jc_javax_naming_ReferralException$method$retryReferral$cc68bec39a495c69(_jc_env *, struct _jc_javax_naming_ReferralException$object *);
extern jboolean _jc_javax_naming_ReferralException$method$skipReferral$83175fe4e83c8b9f(_jc_env *, struct _jc_javax_naming_ReferralException$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_ReferralException$method_info$getReferralContext$ffdbd6221eb269af;
extern _jc_method _jc_javax_naming_ReferralException$method_info$getReferralContext$f81f12c3eb996fff;
extern _jc_method _jc_javax_naming_ReferralException$method_info$getReferralInfo$d16117d1086fa452;
extern _jc_method _jc_javax_naming_ReferralException$method_info$retryReferral$cc68bec39a495c69;
extern _jc_method _jc_javax_naming_ReferralException$method_info$skipReferral$83175fe4e83c8b9f;

// Virtual methods structure
struct _jc_javax_naming_ReferralException$vmethods {
	struct _jc_object	*(*getReferralContext$ffdbd6221eb269af)(_jc_env *, struct _jc_javax_naming_ReferralException$object *);
	struct _jc_object	*(*getReferralContext$f81f12c3eb996fff)(_jc_env *, struct _jc_javax_naming_ReferralException$object *, struct _jc_java_util_Hashtable$object *);
	struct _jc_java_lang_Object$object	*(*getReferralInfo$d16117d1086fa452)(_jc_env *, struct _jc_javax_naming_ReferralException$object *);
	void	(*retryReferral$cc68bec39a495c69)(_jc_env *, struct _jc_javax_naming_ReferralException$object *);
	jboolean	(*skipReferral$83175fe4e83c8b9f)(_jc_env *, struct _jc_javax_naming_ReferralException$object *);
};

// Vtable
struct _jc_javax_naming_ReferralException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_naming_NamingException$vmethods	javax_naming_NamingException;
	_jc_javax_naming_ReferralException$vmethods	javax_naming_ReferralException;
};

// Vtype
struct _jc_javax_naming_ReferralException$vtype {
	_jc_type			type;
	_jc_javax_naming_ReferralException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_ReferralException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_ReferralException$refs {
    _jc_javax_naming_ReferralException$sub_refs	javax_naming_ReferralException;
    _jc_javax_naming_NamingException$sub_refs	javax_naming_NamingException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_ReferralException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_ReferralException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_naming_NamingException$sub_nonrefs	javax_naming_NamingException;
    _jc_javax_naming_ReferralException$sub_nonrefs	javax_naming_ReferralException;
};

// Object instance structure
struct _jc_javax_naming_ReferralException$object {
	_jc_javax_naming_ReferralException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_ReferralException$vtype	*vtype;
	_jc_javax_naming_ReferralException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_ReferralException$vtype _jc_javax_naming_ReferralException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_ReferralException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_ReferralException$class_object;

#endif	/* _JC_javax_naming_ReferralException_H_ */

==> jc-1.4.6.tar.gz: javax/naming/ReferralException.h <==
// public abstract class javax.naming.ReferralException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fadee18b7599c8d5 javax_naming_NamingException
// @dep_class 7961821e227a0a49 javax_naming_ReferralException

// header file dependencies
// @dep_header javax_naming_NamingException

#include "javax/naming/NamingException.h"

#ifndef _JC_javax_naming_ReferralException_H_
#define _JC_javax_naming_ReferralException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_naming_Context$object;

// Typedefs
typedef struct _jc_javax_naming_ReferralException$sub_refs	_jc_javax_naming_ReferralException$sub_refs;
typedef struct _jc_javax_naming_ReferralException$sub_nonrefs	_jc_javax_naming_ReferralException$sub_nonrefs;
typedef struct _jc_javax_naming_ReferralException$refs	_jc_javax_naming_ReferralException$refs;
typedef struct _jc_javax_naming_ReferralException$nonrefs	_jc_javax_naming_ReferralException$nonrefs;
typedef struct _jc_javax_naming_ReferralException$object	_jc_javax_naming_ReferralException$object;

typedef struct _jc_javax_naming_ReferralException$fields_struct	_jc_javax_naming_ReferralException$fields_struct;
typedef const struct _jc_javax_naming_ReferralException$vmethods	_jc_javax_naming_ReferralException$vmethods;
typedef const struct _jc_javax_naming_ReferralException$vtable	_jc_javax_naming_ReferralException$vtable;
typedef const struct _jc_javax_naming_ReferralException$vtype	_jc_javax_naming_ReferralException$vtype;

// Class fields structure
struct _jc_javax_naming_ReferralException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_naming_ReferralException$fields_struct _jc_javax_naming_ReferralException$class_fields;

// Constructors
extern void _jc_javax_naming_ReferralException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_ReferralException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_ReferralException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_ReferralException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_naming_ReferralException$method$getReferralContext$ffdbd6221eb269af(_jc_env *, struct _jc_javax_naming_ReferralException$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_naming_ReferralException$method$getReferralContext$f81f12c3eb996fff(_jc_env *, struct _jc_javax_naming_ReferralException$object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_naming_ReferralException$method$getReferralInfo$d16117d1086fa452(_jc_env *, struct _jc_javax_naming_ReferralException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_ReferralException$method$retryReferral$cc68bec39a495c69(_jc_env *, struct _jc_javax_naming_ReferralException$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_naming_ReferralException$method$skipReferral$83175fe4e83c8b9f(_jc_env *, struct _jc_javax_naming_ReferralException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_ReferralException$method_info$getReferralContext$ffdbd6221eb269af;
extern _jc_method _jc_javax_naming_ReferralException$method_info$getReferralContext$f81f12c3eb996fff;
extern _jc_method _jc_javax_naming_ReferralException$method_info$getReferralInfo$d16117d1086fa452;
extern _jc_method _jc_javax_naming_ReferralException$method_info$retryReferral$cc68bec39a495c69;
extern _jc_method _jc_javax_naming_ReferralException$method_info$skipReferral$83175fe4e83c8b9f;

// Virtual methods structure
struct _jc_javax_naming_ReferralException$vmethods {
	struct _jc_object	*(*getReferralContext$ffdbd6221eb269af)(_jc_env *, struct _jc_javax_naming_ReferralException$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getReferralContext$f81f12c3eb996fff)(_jc_env *, struct _jc_javax_naming_ReferralException$object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getReferralInfo$d16117d1086fa452)(_jc_env *, struct _jc_javax_naming_ReferralException$object *) _JC_JCNI_ATTR;
	void	(*retryReferral$cc68bec39a495c69)(_jc_env *, struct _jc_javax_naming_ReferralException$object *) _JC_JCNI_ATTR;
	jboolean	(*skipReferral$83175fe4e83c8b9f)(_jc_env *, struct _jc_javax_naming_ReferralException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_ReferralException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_naming_NamingException$vmethods	javax_naming_NamingException;
	_jc_javax_naming_ReferralException$vmethods	javax_naming_ReferralException;
};

// Vtype
struct _jc_javax_naming_ReferralException$vtype {
	_jc_type			type;
	_jc_javax_naming_ReferralException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_ReferralException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_ReferralException$refs {
    _jc_javax_naming_ReferralException$sub_refs	javax_naming_ReferralException;
    _jc_javax_naming_NamingException$sub_refs	javax_naming_NamingException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_ReferralException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_ReferralException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_naming_NamingException$sub_nonrefs	javax_naming_NamingException;
    _jc_javax_naming_ReferralException$sub_nonrefs	javax_naming_ReferralException;
};

// Object instance structure
struct _jc_javax_naming_ReferralException$object {
	_jc_javax_naming_ReferralException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_ReferralException$vtype	*vtype;
	_jc_javax_naming_ReferralException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_ReferralException$vtype _jc_javax_naming_ReferralException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_ReferralException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_ReferralException$class_object;

#endif	/* _JC_javax_naming_ReferralException_H_ */
